@@ -12,23 +12,16 @@ class Boards(Enum):
     IMXRT1050_EVKB = 'IMXRT1050-EVKB'
     STM32F407G_DISCO = 'STM32F407G-DISCO'
     STM32F411E_DISCO = 'STM32F411E-DISCO'
-    STM32F469I_DISCO = 'STM32F469I-DISCO'
     STM32F769I_DISCO = 'STM32F769I-DISCO'
-    STM32H735G_DK = 'STM32H735G-DK'
-    STM32H747I_DISCO = 'STM32H747I-DISCO'
 
 
 _BOARD_TO_MCU = {
     Boards.IMXRT1050_EVKB: Microcontrollers.IMXRT,
     Boards.STM32F407G_DISCO: Microcontrollers.STM32,
     Boards.STM32F411E_DISCO: Microcontrollers.STM32,
-    Boards.STM32F469I_DISCO: Microcontrollers.STM32,
     Boards.STM32F769I_DISCO: Microcontrollers.STM32,
-    Boards.STM32H735G_DK: Microcontrollers.STM32,
-    Boards.STM32H747I_DISCO: Microcontrollers.STM32,
 }
 
-
 assert len(_BOARD_TO_MCU) == len(Boards)
 
 
