@@ -35,6 +35,7 @@ def serialize_to_file(ppn_path, rhn_path, access_key, param_path):
         f.write(access_key.encode())
         f.write(b'\0')
 
+
 def _upload_param_imxrt1050(param_path, num_retries=3):
     tools_folder = board_tools_folder(Boards.IMXRT1050_EVKB)
     programmer_path = os.path.join(tools_folder, 'crt_emu_cm_redlink')
@@ -63,49 +64,6 @@ def _upload_param_imxrt1050(param_path, num_retries=3):
     raise RuntimeError("Failed to upload the params to the board")
 
 
-def _upload_param_stm32f469(param_path):
-    tools_folder = board_tools_folder(Boards.STM32F469I_DISCO)
-    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
-
-    command = '%s --connect port=SWD ap=0' % programmer_path
-    log.debug(command)
-
-    res = subprocess.Popen(
-        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
-    log.debug(res)
-    if 'stm32f469' not in res.lower():
-        raise RuntimeError("Failed to connect to the board")
-
-    magic_address = '0x081e0000'
-    command = '%s --connect port=SWD ap=0 -w %s %s -hardRst' % (programmer_path, param_path, magic_address)
-    log.debug(command)
-
-    res = subprocess.run(command, **subprocess_run_kwargs).returncode
-    if res != 0:
-        raise RuntimeError("Failed to upload the params to the board")
-
-def _upload_param_stm32h735(param_path):
-    tools_folder = board_tools_folder(Boards.STM32H735G_DK)
-    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
-
-    command = '%s --connect port=SWD ap=0' % programmer_path
-    log.debug(command)
-
-    res = subprocess.Popen(
-        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
-    log.debug(res)
-    if 'stm32h73x' not in res.lower():
-        raise RuntimeError("Failed to connect to the board")
-
-    magic_address = '0x080e0000'
-    command = '%s --connect port=SWD ap=0 -w %s %s -hardRst' % (programmer_path, param_path, magic_address)
-    log.debug(command)
-
-    res = subprocess.run(command, **subprocess_run_kwargs).returncode
-    if res != 0:
-        raise RuntimeError("Failed to upload the params to the board")
-
-
 def _upload_param_stm32f769(param_path):
     tools_folder = board_tools_folder(Boards.STM32F769I_DISCO)
     programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
@@ -127,6 +85,7 @@ def _upload_param_stm32f769(param_path):
     if res != 0:
         raise RuntimeError("Failed to upload the params to the board")
 
+
 def _upload_param_stm32f407(param_path):
     tools_folder = board_tools_folder(Boards.STM32F407G_DISCO)
     programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
@@ -171,28 +130,6 @@ def _upload_param_stm32f411(param_path):
         raise RuntimeError("Failed to upload the params to the board")
 
 
-def _upload_param_stm32h747(param_path):
-    tools_folder = board_tools_folder(Boards.STM32H747I_DISCO)
-    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
-
-    command = '%s --connect port=SWD ap=0' % programmer_path
-    log.debug(command)
-
-    res = subprocess.Popen(
-        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
-    log.debug(res)
-    if 'stm32h747' not in res.lower():
-        raise RuntimeError("Failed to connect to the board")
-
-    magic_address = '0x08160000'
-    command = '%s --connect port=SWD ap=3 -w %s %s -hardRst' % (programmer_path, param_path, magic_address)
-    log.debug(command)
-
-    res = subprocess.run(command, **subprocess_run_kwargs).returncode
-    if res != 0:
-        raise RuntimeError("Failed to upload the params to the board")
-
-
 def upload_params(ppn_path, rhn_path, access_key, board):
     param_path = os.path.join(tempfile.gettempdir(), str(uuid.uuid4()) + '.bin')
     serialize_to_file(ppn_path=ppn_path, rhn_path=rhn_path, access_key=access_key, param_path=param_path)
@@ -204,14 +141,8 @@ def upload_params(ppn_path, rhn_path, access_key, board):
             _upload_param_stm32f407(param_path)
         elif board is Boards.STM32F411E_DISCO:
             _upload_param_stm32f411(param_path)
-        elif board is Boards.STM32F469I_DISCO:
-            _upload_param_stm32f469(param_path)
         elif board is Boards.STM32F769I_DISCO:
             _upload_param_stm32f769(param_path)
-        elif board is Boards.STM32H747I_DISCO:
-            _upload_param_stm32h747(param_path)
-        elif board is Boards.STM32H735G_DK:
-            _upload_param_stm32h735(param_path)
         else:
             raise ValueError("Unsupported board '%s'" % str(board))
     finally:
